#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# require 'wget/toplevel_methods.rb'
# =========================================================================== #
class Wget

  # ========================================================================= #
  # === Wget.download_to?
  # ========================================================================= #
  def self.download_to?
    LAST_DOWNLOADED_FILE
  end

  # ========================================================================= #
  # === Wget.check_if_remote_file_exists
  #
  # This method will return a boolean value - true if the remote website
  # (remote URL) exists, and false otherwise. The functionality depends
  # on the availability of wget.
  #
  # The first argument is the target file.
  #
  # Invocation example:
  #
  #   Wget.does_this_remote_website_exist? 'http://shevegen.square7.ch/rbt_changelog.html'
  #
  # ========================================================================= #
  def self.check_if_remote_file_exists(this_file)
    # ======================================================================= #
    # Use wget --spider to check if the remote file exists.
    # ======================================================================= #
    _ = "wget --spider -v #{this_file} 2>&1"
    result = `#{_}`
    if result.include?('Remote file exists') or # Yes, the remote file exists.
       result =~ /File '.+' exists./
      remote_file_exists = true
    else
      remote_file_exists = false
    end
    if result.include? '/404'
      remote_file_exists = false
    end
    return remote_file_exists
  end; self.instance_eval { alias does_this_remote_website_exist? check_if_remote_file_exists } # === Wget.does_this_remote_website_exist?

  # ========================================================================= #
  # === Wget.download
  # ========================================================================= #
  def self.download(this_file)
    _ = Wget.new(this_file)
    _.try_to_report_where_we_downloaded_the_file
  end

end